==> TencentNavKitDocument_7.2.1.zip: TencentNavKitDocument/search/functions_d.js <==
var searchData=
[
  ['walknavmanager_3adidstartrerouting_3a_0',['walkNavManager:didStartRerouting:',['../protocol_t_n_k_walk_nav_delegate-p.html#aed7ce49214b63189d24271b1d729b30e',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3adidupdatelocation_3a_1',['walkNavManager:didUpdateLocation:',['../protocol_t_n_k_walk_nav_delegate-p.html#a2583213413a9b69ae0cf673852062caf',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3agpsstatusdidchange_3a_2',['walkNavManager:gpsStatusDidChange:',['../protocol_t_n_k_walk_nav_delegate-p.html#a41efc870e28ed3bb94e740281fce1d8d',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3anavitts_3a_3',['walkNavManager:naviTTS:',['../protocol_t_n_k_walk_nav_data_source-p.html#afdef868aca09ab733740fbdb0aa39de6',1,'TNKWalkNavDataSource-p']]],
  ['walknavmanager_3areroutedidfail_3a_4',['walkNavManager:rerouteDidFail:',['../protocol_t_n_k_walk_nav_delegate-p.html#a0d2c40c705b0d2c2afacc18b64b0608c',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3areroutedidsuccess_3a_5',['walkNavManager:rerouteDidSuccess:',['../protocol_t_n_k_walk_nav_delegate-p.html#a17c30c7b8a1b44ee1e62acd2d243b863',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3aupdatelocationfailedwitherror_3a_6',['walkNavManager:updateLocationFailedWithError:',['../protocol_t_n_k_walk_nav_delegate-p.html#af939fa46ffbbabbe0fb6a6e069606d2f',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3aupdatenavigationdata_3a_7',['walkNavManager:updateNavigationData:',['../protocol_t_n_k_walk_nav_delegate-p.html#af98c114d72a8deefb7c6b526e83bd43d',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanagerdidstart_3a_8',['walkNavManagerDidStart:',['../protocol_t_n_k_walk_nav_delegate-p.html#a89665dc3765eaa24190574afdfdcec5d',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanagerdidstop_3a_9',['walkNavManagerDidStop:',['../protocol_t_n_k_walk_nav_delegate-p.html#ade458fd8453e0ae1603781c92d822674',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanagerwillarrivedestination_3a_10',['walkNavManagerWillArriveDestination:',['../protocol_t_n_k_walk_nav_delegate-p.html#a0d800ef93f821d1535ebf2a9b5c44715',1,'TNKWalkNavDelegate-p']]],
  ['withguidedlaneenabled_11',['withGuidedLaneEnabled',['../interface_t_n_k_drive_nav_view.html#ae21df8186deef733f41027b598402184',1,'TNKDriveNavView::withGuidedLaneEnabled()'],['../interface_t_n_k_travel_nav_view.html#a8a333a826b8580f1aad1c0df96714d58',1,'TNKTravelNavView::withGuidedLaneEnabled()']]],
  ['withnavigationpanelenabled_12',['withNavigationPanelEnabled',['../interface_t_n_k_drive_nav_view.html#a0da7d2a050f126387db02e1a21499fa6',1,'TNKDriveNavView::withNavigationPanelEnabled()'],['../interface_t_n_k_travel_nav_view.html#ac20b55c31107e5db1b7dcf0b2f2fa482',1,'TNKTravelNavView::withNavigationPanelEnabled()']]],
  ['withpanelbuttomgap_13',['withPanelButtomGap',['../interface_t_n_k_travel_nav_view.html#a8d55accab391b3655e2bbd82e469dd2a',1,'TNKTravelNavView']]],
  ['withpaneltopgap_14',['withPanelTopGap',['../interface_t_n_k_drive_nav_view.html#af854f12782c7f2db7ab03cd145616b01',1,'TNKDriveNavView::withPanelTopGap()'],['../interface_t_n_k_travel_nav_view.html#a82a6aa84b8a90b8172ddc84861e8f304',1,'TNKTravelNavView::withPanelTopGap()']]],
  ['withshowbottomtoolbar_15',['withShowBottomToolbar',['../interface_t_n_k_drive_nav_view.html#a56516112ecd46ff74d006dec9d36380c',1,'TNKDriveNavView::withShowBottomToolbar()'],['../interface_t_n_k_travel_nav_view.html#abc5cf871f0475399a05b0e95f0a2f594',1,'TNKTravelNavView::withShowBottomToolbar()']]],
  ['withshowbroadcastbutton_16',['withShowBroadCastButton',['../interface_t_n_k_drive_nav_view.html#a0500f1c3286fb1c44eab794ded1846f7',1,'TNKDriveNavView::withShowBroadCastButton()'],['../interface_t_n_k_travel_nav_view.html#ad83822c287d95ea8c455219c3c38cc42',1,'TNKTravelNavView::withShowBroadCastButton()']]],
  ['withshowcurrentspeedview_17',['withShowCurrentSpeedView',['../interface_t_n_k_drive_nav_view.html#a0e914cd02c5a69e9918f2cef474fcbdb',1,'TNKDriveNavView::withShowCurrentSpeedView()'],['../interface_t_n_k_travel_nav_view.html#a88646a69bf234b5007ad951aa5347c81',1,'TNKTravelNavView::withShowCurrentSpeedView()']]],
  ['withshowexitbutton_18',['withShowExitButton',['../interface_t_n_k_drive_nav_view.html#a41aa6b1e078146e1547e8f2ae8790fb4',1,'TNKDriveNavView::withShowExitButton()'],['../interface_t_n_k_travel_nav_view.html#a8ea4c4639a9c0d96907dac58c10e083e',1,'TNKTravelNavView::withShowExitButton()']]],
  ['withshowgrossspeedingview_19',['withShowGrossSpeedingView',['../interface_t_n_k_drive_nav_view.html#af50957d818cb41d75cb324df2935c1c3',1,'TNKDriveNavView::withShowGrossSpeedingView()'],['../interface_t_n_k_travel_nav_view.html#a3b27474118583672ba634d3a03f986f5',1,'TNKTravelNavView::withShowGrossSpeedingView()']]],
  ['withshowlimitspeedandcurrentroadnameview_20',['withShowLimitSpeedAndCurrentRoadNameView',['../interface_t_n_k_drive_nav_view.html#a7a888aa188e40c53b4d06e5efe27c116',1,'TNKDriveNavView::withShowLimitSpeedAndCurrentRoadNameView()'],['../interface_t_n_k_travel_nav_view.html#ae830bebae92b9197e3889fb32a15df3b',1,'TNKTravelNavView::withShowLimitSpeedAndCurrentRoadNameView()']]],
  ['withshowmaptrafficbutton_21',['withShowMapTrafficButton',['../interface_t_n_k_drive_nav_view.html#a06597e08ee9e60304db214adf39b9c92',1,'TNKDriveNavView::withShowMapTrafficButton()'],['../interface_t_n_k_travel_nav_view.html#a2298872356d66f13dc7924f41499e1d6',1,'TNKTravelNavView::withShowMapTrafficButton()']]],
  ['withshowoverviewbutton_22',['withShowOverviewButton',['../interface_t_n_k_drive_nav_view.html#ab8c89362e4c5b837947fc76b3a2c4f0f',1,'TNKDriveNavView::withShowOverviewButton()'],['../interface_t_n_k_travel_nav_view.html#a8387b6d4d6b49721c96f1bd4185f1182',1,'TNKTravelNavView::withShowOverviewButton()']]],
  ['withshowroadtypebutton_23',['withShowRoadTypeButton',['../interface_t_n_k_drive_nav_view.html#a576101e71ffbd9e1b5115c88af15920d',1,'TNKDriveNavView::withShowRoadTypeButton()'],['../interface_t_n_k_travel_nav_view.html#a966ca8e06e445ff7a0cfb39645319485',1,'TNKTravelNavView::withShowRoadTypeButton()']]],
  ['withshowrouterefreshbutton_24',['withShowRouteRefreshButton',['../interface_t_n_k_drive_nav_view.html#afa140764ce3201e5430f49c43c3042d2',1,'TNKDriveNavView::withShowRouteRefreshButton()'],['../interface_t_n_k_travel_nav_view.html#ad574e9ea70dfcaa5e84bb6de29d02c8b',1,'TNKTravelNavView::withShowRouteRefreshButton()']]],
  ['withshowserviceareainfo_25',['withShowServiceAreaInfo',['../interface_t_n_k_drive_nav_view.html#abff7c5a842ede61505ae67927bc98a0b',1,'TNKDriveNavView::withShowServiceAreaInfo()'],['../interface_t_n_k_travel_nav_view.html#a2c9be63b80ad747de5b9d7eca310cc60',1,'TNKTravelNavView::withShowServiceAreaInfo()']]],
  ['withshowsettingbutton_26',['withShowSettingButton',['../interface_t_n_k_drive_nav_view.html#a63f823621a265d8a7a4f01a323e7cdf1',1,'TNKDriveNavView::withShowSettingButton()'],['../interface_t_n_k_travel_nav_view.html#a07f8f94884303e8ff0a92e1502cea210',1,'TNKTravelNavView::withShowSettingButton()']]],
  ['withshowsmartlocview_27',['withShowSmartLocView',['../interface_t_n_k_drive_nav_view.html#a4acdd6e4b028ba39c7b75f15a8eb0c5c',1,'TNKDriveNavView::withShowSmartLocView()'],['../interface_t_n_k_travel_nav_view.html#a8fe4a42fe3f17507004318c383eb5a00',1,'TNKTravelNavView::withShowSmartLocView()']]],
  ['withshowtoast_28',['withShowToast',['../interface_t_n_k_drive_nav_view.html#a03e10391012abf81465547062ea27132',1,'TNKDriveNavView::withShowToast()'],['../interface_t_n_k_travel_nav_view.html#a6eb6f87601c2ea9c8bff29d59219ebdb',1,'TNKTravelNavView::withShowToast()']]],
  ['withshowtrafficbar_29',['withShowTrafficBar',['../interface_t_n_k_drive_nav_view.html#aa349c50085c81152f38d0d6d0e979923',1,'TNKDriveNavView::withShowTrafficBar()'],['../interface_t_n_k_travel_nav_view.html#adcf8c0bd260ebe2615b9a54baf0a2bfc',1,'TNKTravelNavView::withShowTrafficBar()']]],
  ['withshowuielements_30',['withShowUIElements',['../interface_t_n_k_drive_nav_view.html#a723803fbc0af23188557a3c0f5a44ee4',1,'TNKDriveNavView::withShowUIElements()'],['../interface_t_n_k_travel_nav_view.html#add8668d86629e8134ddba790a701752c',1,'TNKTravelNavView::withShowUIElements()']]],
  ['writelogtext_3a_31',['writeLogText:',['../interface_t_n_k_logger.html#a17d012cf568520ec62c92027a4a31d90',1,'TNKLogger']]]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/search/functions_d.js <==
var searchData=
[
  ['walknavmanager_3adidstartrerouting_3a_0',['walkNavManager:didStartRerouting:',['../protocol_t_n_k_walk_nav_delegate-p.html#aed7ce49214b63189d24271b1d729b30e',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3adidupdatelocation_3a_1',['walkNavManager:didUpdateLocation:',['../protocol_t_n_k_walk_nav_delegate-p.html#a2583213413a9b69ae0cf673852062caf',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3agpsstatusdidchange_3a_2',['walkNavManager:gpsStatusDidChange:',['../protocol_t_n_k_walk_nav_delegate-p.html#a41efc870e28ed3bb94e740281fce1d8d',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3anavitts_3a_3',['walkNavManager:naviTTS:',['../protocol_t_n_k_walk_nav_data_source-p.html#afdef868aca09ab733740fbdb0aa39de6',1,'TNKWalkNavDataSource-p']]],
  ['walknavmanager_3areroutedidfail_3a_4',['walkNavManager:rerouteDidFail:',['../protocol_t_n_k_walk_nav_delegate-p.html#a0d2c40c705b0d2c2afacc18b64b0608c',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3areroutedidsuccess_3a_5',['walkNavManager:rerouteDidSuccess:',['../protocol_t_n_k_walk_nav_delegate-p.html#a17c30c7b8a1b44ee1e62acd2d243b863',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3aupdatelocationfailedwitherror_3a_6',['walkNavManager:updateLocationFailedWithError:',['../protocol_t_n_k_walk_nav_delegate-p.html#af939fa46ffbbabbe0fb6a6e069606d2f',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanager_3aupdatenavigationdata_3a_7',['walkNavManager:updateNavigationData:',['../protocol_t_n_k_walk_nav_delegate-p.html#af98c114d72a8deefb7c6b526e83bd43d',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanagerdidstart_3a_8',['walkNavManagerDidStart:',['../protocol_t_n_k_walk_nav_delegate-p.html#a89665dc3765eaa24190574afdfdcec5d',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanagerdidstop_3a_9',['walkNavManagerDidStop:',['../protocol_t_n_k_walk_nav_delegate-p.html#ade458fd8453e0ae1603781c92d822674',1,'TNKWalkNavDelegate-p']]],
  ['walknavmanagerwillarrivedestination_3a_10',['walkNavManagerWillArriveDestination:',['../protocol_t_n_k_walk_nav_delegate-p.html#a0d800ef93f821d1535ebf2a9b5c44715',1,'TNKWalkNavDelegate-p']]],
  ['withguidedlaneenabled_11',['withGuidedLaneEnabled',['../interface_t_n_k_drive_nav_view.html#ae21df8186deef733f41027b598402184',1,'TNKDriveNavView::withGuidedLaneEnabled()'],['../interface_t_n_k_travel_nav_view.html#a8a333a826b8580f1aad1c0df96714d58',1,'TNKTravelNavView::withGuidedLaneEnabled()']]],
  ['withnavigationpanelenabled_12',['withNavigationPanelEnabled',['../interface_t_n_k_drive_nav_view.html#a0da7d2a050f126387db02e1a21499fa6',1,'TNKDriveNavView::withNavigationPanelEnabled()'],['../interface_t_n_k_travel_nav_view.html#ac20b55c31107e5db1b7dcf0b2f2fa482',1,'TNKTravelNavView::withNavigationPanelEnabled()']]],
  ['withpanelbuttomgap_13',['withPanelButtomGap',['../interface_t_n_k_travel_nav_view.html#a8d55accab391b3655e2bbd82e469dd2a',1,'TNKTravelNavView']]],
  ['withpaneltopgap_14',['withPanelTopGap',['../interface_t_n_k_drive_nav_view.html#af854f12782c7f2db7ab03cd145616b01',1,'TNKDriveNavView::withPanelTopGap()'],['../interface_t_n_k_travel_nav_view.html#a82a6aa84b8a90b8172ddc84861e8f304',1,'TNKTravelNavView::withPanelTopGap()']]],
  ['withshowbottomtoolbar_15',['withShowBottomToolbar',['../interface_t_n_k_drive_nav_view.html#a56516112ecd46ff74d006dec9d36380c',1,'TNKDriveNavView::withShowBottomToolbar()'],['../interface_t_n_k_travel_nav_view.html#abc5cf871f0475399a05b0e95f0a2f594',1,'TNKTravelNavView::withShowBottomToolbar()']]],
  ['withshowbroadcastbutton_16',['withShowBroadCastButton',['../interface_t_n_k_drive_nav_view.html#a0500f1c3286fb1c44eab794ded1846f7',1,'TNKDriveNavView::withShowBroadCastButton()'],['../interface_t_n_k_travel_nav_view.html#ad83822c287d95ea8c455219c3c38cc42',1,'TNKTravelNavView::withShowBroadCastButton()']]],
  ['withshowcurrentspeedview_17',['withShowCurrentSpeedView',['../interface_t_n_k_drive_nav_view.html#a0e914cd02c5a69e9918f2cef474fcbdb',1,'TNKDriveNavView::withShowCurrentSpeedView()'],['../interface_t_n_k_travel_nav_view.html#a88646a69bf234b5007ad951aa5347c81',1,'TNKTravelNavView::withShowCurrentSpeedView()']]],
  ['withshowexitbutton_18',['withShowExitButton',['../interface_t_n_k_drive_nav_view.html#a41aa6b1e078146e1547e8f2ae8790fb4',1,'TNKDriveNavView::withShowExitButton()'],['../interface_t_n_k_travel_nav_view.html#a8ea4c4639a9c0d96907dac58c10e083e',1,'TNKTravelNavView::withShowExitButton()']]],
  ['withshowgrossspeedingview_19',['withShowGrossSpeedingView',['../interface_t_n_k_drive_nav_view.html#af50957d818cb41d75cb324df2935c1c3',1,'TNKDriveNavView::withShowGrossSpeedingView()'],['../interface_t_n_k_travel_nav_view.html#a3b27474118583672ba634d3a03f986f5',1,'TNKTravelNavView::withShowGrossSpeedingView()']]],
  ['withshowlimitspeedandcurrentroadnameview_20',['withShowLimitSpeedAndCurrentRoadNameView',['../interface_t_n_k_drive_nav_view.html#a7a888aa188e40c53b4d06e5efe27c116',1,'TNKDriveNavView::withShowLimitSpeedAndCurrentRoadNameView()'],['../interface_t_n_k_travel_nav_view.html#ae830bebae92b9197e3889fb32a15df3b',1,'TNKTravelNavView::withShowLimitSpeedAndCurrentRoadNameView()']]],
  ['withshowmaptrafficbutton_21',['withShowMapTrafficButton',['../interface_t_n_k_drive_nav_view.html#a06597e08ee9e60304db214adf39b9c92',1,'TNKDriveNavView::withShowMapTrafficButton()'],['../interface_t_n_k_travel_nav_view.html#a2298872356d66f13dc7924f41499e1d6',1,'TNKTravelNavView::withShowMapTrafficButton()']]],
  ['withshowoverviewbutton_22',['withShowOverviewButton',['../interface_t_n_k_drive_nav_view.html#ab8c89362e4c5b837947fc76b3a2c4f0f',1,'TNKDriveNavView::withShowOverviewButton()'],['../interface_t_n_k_travel_nav_view.html#a8387b6d4d6b49721c96f1bd4185f1182',1,'TNKTravelNavView::withShowOverviewButton()']]],
  ['withshowroadtypebutton_23',['withShowRoadTypeButton',['../interface_t_n_k_drive_nav_view.html#a576101e71ffbd9e1b5115c88af15920d',1,'TNKDriveNavView::withShowRoadTypeButton()'],['../interface_t_n_k_travel_nav_view.html#a966ca8e06e445ff7a0cfb39645319485',1,'TNKTravelNavView::withShowRoadTypeButton()']]],
  ['withshowrouteexplain_24',['withShowRouteExplain',['../interface_t_n_k_drive_nav_view.html#a97836913af594f034b3eb39dd0a42189',1,'TNKDriveNavView::withShowRouteExplain()'],['../interface_t_n_k_travel_nav_view.html#a01cc3d5bb28be566e76d858a194fb43e',1,'TNKTravelNavView::withShowRouteExplain()']]],
  ['withshowrouterefreshbutton_25',['withShowRouteRefreshButton',['../interface_t_n_k_drive_nav_view.html#afa140764ce3201e5430f49c43c3042d2',1,'TNKDriveNavView::withShowRouteRefreshButton()'],['../interface_t_n_k_travel_nav_view.html#ad574e9ea70dfcaa5e84bb6de29d02c8b',1,'TNKTravelNavView::withShowRouteRefreshButton()']]],
  ['withshowserviceareainfo_26',['withShowServiceAreaInfo',['../interface_t_n_k_drive_nav_view.html#abff7c5a842ede61505ae67927bc98a0b',1,'TNKDriveNavView::withShowServiceAreaInfo()'],['../interface_t_n_k_travel_nav_view.html#a2c9be63b80ad747de5b9d7eca310cc60',1,'TNKTravelNavView::withShowServiceAreaInfo()']]],
  ['withshowsettingbutton_27',['withShowSettingButton',['../interface_t_n_k_drive_nav_view.html#a63f823621a265d8a7a4f01a323e7cdf1',1,'TNKDriveNavView::withShowSettingButton()'],['../interface_t_n_k_travel_nav_view.html#a07f8f94884303e8ff0a92e1502cea210',1,'TNKTravelNavView::withShowSettingButton()']]],
  ['withshowsmartlocview_28',['withShowSmartLocView',['../interface_t_n_k_drive_nav_view.html#a4acdd6e4b028ba39c7b75f15a8eb0c5c',1,'TNKDriveNavView::withShowSmartLocView()'],['../interface_t_n_k_travel_nav_view.html#a8fe4a42fe3f17507004318c383eb5a00',1,'TNKTravelNavView::withShowSmartLocView()']]],
  ['withshowtoast_29',['withShowToast',['../interface_t_n_k_drive_nav_view.html#a03e10391012abf81465547062ea27132',1,'TNKDriveNavView::withShowToast()'],['../interface_t_n_k_travel_nav_view.html#a6eb6f87601c2ea9c8bff29d59219ebdb',1,'TNKTravelNavView::withShowToast()']]],
  ['withshowtrafficbar_30',['withShowTrafficBar',['../interface_t_n_k_drive_nav_view.html#aa349c50085c81152f38d0d6d0e979923',1,'TNKDriveNavView::withShowTrafficBar()'],['../interface_t_n_k_travel_nav_view.html#adcf8c0bd260ebe2615b9a54baf0a2bfc',1,'TNKTravelNavView::withShowTrafficBar()']]],
  ['withshowuielements_31',['withShowUIElements',['../interface_t_n_k_drive_nav_view.html#a723803fbc0af23188557a3c0f5a44ee4',1,'TNKDriveNavView::withShowUIElements()'],['../interface_t_n_k_travel_nav_view.html#add8668d86629e8134ddba790a701752c',1,'TNKTravelNavView::withShowUIElements()']]],
  ['writelogtext_3a_32',['writeLogText:',['../interface_t_n_k_logger.html#a17d012cf568520ec62c92027a4a31d90',1,'TNKLogger']]]
];
